@@ -1,5 +1,6 @@
 import sys
 import time
+from contextlib import suppress
 from pathlib import Path
 
 import pkg_resources
@@ -24,8 +25,22 @@ from activate.app import activity_view, connect, maps, paths, settings, sync, wi
 from activate.app.ui.main import Ui_main_window
 
 SYNC_PROGRESS_STEPS = 1000
+
 SYNC_WAIT_DIVISIONS = 100
 SYNC_DELAY = 2
+GET_TICKS = round(0.3 * SYNC_WAIT_DIVISIONS)
+ADD_TICKS = round(0.05 * SYNC_WAIT_DIVISIONS)
+
+
+def get_unsynced_edited():
+    try:
+        return set(serialise.load(paths.UNSYNCED_EDITED))
+    except FileNotFoundError:
+        return set()
+
+
+def save_unsynced_edited(data):
+    serialise.dump(list(data), paths.UNSYNCED_EDITED)
 
 
 class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
@@ -37,6 +52,7 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
 
         self.settings = settings.load_settings()
         self.hide_unused_things()
+        self.unsynced_edited_activities = get_unsynced_edited()
 
         # Create a global map widget to be used everywhere. This is
         # necessary because pyqtlet doesn't support multiple L.map
@@ -58,6 +74,7 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
             (self.action_import, "document-open"),
             (self.action_add_manual, "document-new"),
             (self.action_edit, "document-edit"),
+            (self.action_match, "document-equal"),
             (self.action_analyse, "view-statistics"),
             (self.action_add_photos, "insert-image"),
             (self.action_general, "settings-configure"),
@@ -109,6 +126,7 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
                     ),
                     "[manual]",
                     data["Flags"],
+                    data["Effort"],
                     data["Start Time"],
                     data["Distance"] * 1000,
                     description=data["Description"],
@@ -147,8 +165,10 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
         if new_activity_count == 0:
             dialog.reset()
             return
-        dialog.setMaximum(new_activity_count * SYNC_WAIT_DIVISIONS)
-        for progress in range(1, SYNC_WAIT_DIVISIONS):
+        dialog.setMaximum(
+            new_activity_count * SYNC_WAIT_DIVISIONS + GET_TICKS + ADD_TICKS
+        )
+        for progress in range(GET_TICKS, SYNC_WAIT_DIVISIONS):
             dialog.setValue(progress)
             time.sleep(SYNC_DELAY / SYNC_WAIT_DIVISIONS)
             if dialog.wasCanceled():
@@ -157,19 +177,22 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
         done = False
         self.activity_list_table.setSortingEnabled(False)
         for index, new_activity in enumerate(new_activities):
-            dialog.setLabelText(f"Syncing {new_activity.name}")
-            progress += 1
+            progress += GET_TICKS
             dialog.setValue(progress)
+            dialog.setLabelText(f"Syncing {new_activity.name}")
             self.add_activity(new_activity)
+            progress += ADD_TICKS
+            dialog.setValue(progress)
             if index < new_activity_count - 1:
-                for i in range(SYNC_WAIT_DIVISIONS - 1):
-                    progress += 1
+                for progress in range(progress, (index + 2) * SYNC_WAIT_DIVISIONS):
                     dialog.setValue(progress)
                     time.sleep(SYNC_DELAY / SYNC_WAIT_DIVISIONS)
                     if dialog.wasCanceled():
                         done = True
             if done:
                 break
+        else:
+            dialog.setValue(progress + 1)
         sync.sync_state.write()
 
         self.activity_list_table.setCurrentCell(0, 0)
@@ -291,7 +314,7 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
             to_delete = self.activity
             for row in range(len(self.activities)):
                 item = self.activity_list_table.item(row, 0)
-                if self.activities.get_activity(item.activity_id) is to_delete:
+                if item.activity_id == to_delete.activity_id:
                     self.activity_list_table.removeRow(row)
                     break
             self.activities.remove(to_delete.activity_id)
@@ -300,10 +323,8 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
         self.activity_list_table.setSortingEnabled(False)
         for row in range(len(self.activities)):
             if (
-                self.activities.get_activity(
-                    self.activity_list_table.item(row, 0).activity_id
-                )
-                == self.activity
+                self.activity_list_table.item(row, 0).activity_id
+                == self.activity.activity_id
             ):
                 self.activity_list_table.set_id_row(
                     self.activity.activity_id,
@@ -317,11 +338,8 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
         if self.activity.sport != previous_sport:
             self.summary.update_activity_types_list()
 
-        for server in self.settings.servers:
-            try:
-                server.upload_activity(self.activity)
-            except connect.requests.RequestException:
-                continue
+        self.unsynced_edited_activities.add(self.activity.activity_id)
+        save_unsynced_edited(self.unsynced_edited_activities)
 
     def add_photos(self):
         """Open the Add Photos dialog."""
@@ -467,17 +485,21 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
                     )
                 )
             dialog.setValue(round(SYNC_PROGRESS_STEPS * (i + 2 / 3)))
+            own_ids |= self.unsynced_edited_activities
             if not own_ids:
                 continue
             dialog.setLabelText(f"Uploading activities to {server.name}")
             for j, missing_id in enumerate(own_ids):
                 try:
                     server.upload_activity(self.activities.get_activity(missing_id))
+                    with suppress(KeyError):
+                        self.unsynced_edited_activities.remove(missing_id)
                 except connect.requests.RequestException:
                     break
                 dialog.setValue(
                     round(SYNC_PROGRESS_STEPS * (i + (2 + (1 + j) / len(own_ids)) / 3))
                 )
+        save_unsynced_edited(self.unsynced_edited_activities)
         dialog.setValue(SYNC_PROGRESS_STEPS * len(self.settings.servers))
 
     def social_tab_update(self):
