@@ -4,6 +4,8 @@ import requests
 
 from activate import serialise
 
+TIMEOUT = 4
+
 
 @dataclass
 class Server:
@@ -14,13 +16,15 @@ class Server:
 
     def post_data(self, page, data) -> bytes:
         """Send a POST request to address/page with data."""
-        r = requests.post(self.api_address(page), data=data, auth=self.auth)
+        r = requests.post(
+            self.api_address(page), data=data, auth=self.auth, timeout=TIMEOUT
+        )
         r.raise_for_status()
         return r.content
 
     def get_data(self, page) -> bytes:
         """Send a GET request to address/page."""
-        r = requests.get(self.api_address(page), auth=self.auth)
+        r = requests.get(self.api_address(page), auth=self.auth, timeout=TIMEOUT)
         r.raise_for_status()
         return r.content
 
