@@ -8,9 +8,11 @@ from activate.app import connect, paths
 
 DEFAULTS = {
     "tiles": None,
+    "map_speed": 0.0,
     "unit_system": units.DEFAULT,
     "servers": [],
     "custom_units": {},
+    "cookie": None,
 }
 
 
@@ -29,10 +31,16 @@ class Settings:
     """A settings configuration."""
 
     tiles: Optional[str]
+    map_speed: float
     unit_system: str
     custom_units: dict
     servers: list
+    cookie: Optional[str]
 
     def save(self):
         """Save settings to a configuration file."""
         serialise.dump(dataclasses.asdict(self), paths.SETTINGS, readable=True)
+
+    def copy_from(self, other):
+        for field in dataclasses.fields(self):
+            setattr(self, field.name, getattr(other, field.name))
